<?php
	$_SESSION['nume_slogan'] = 'Aplicatie Dedicata Informarii Consilierilor, Membrii Consililui Local (ADICMCL)<br />- Institutia unde urmeaza sa fie implementata -<br />Versiune 1.0';
	$_SESSION['nume_antet'] = '<a href="http://'.$_SERVER['SERVER_NAME'].'">
					<img id="foto" alt="'.$_SERVER['SERVER_NAME'].'" title="'.$_SERVER['SERVER_NAME'].'" src="http://'.$_SERVER['SERVER_NAME'].'/img/drapel-giurgiu.png" />
					</a>';
	
	$_SESSION['nume_pag1'] = '<br>Acasa';
	$_SESSION['nume_pag2'] = '<br>Acasa';
	$_SESSION['nume_pag3'] = 'Proiecte pe Comisii de specialitate';
	$_SESSION['nume_pag4'] = '<br>Deconectare';
	$_SESSION['nume_pag5'] = '';
	
	$_SESSION['nume_pag1a'] = 'Sedinta<br>noua';
	$_SESSION['nume_pag1b'] = '<br>Acasa';
	$_SESSION['nume_pag2a'] = 'Proiecte<br>Sedinta';
	$_SESSION['nume_pag3a'] = 'Comisii<br>specialitate';
	$_SESSION['nume_pag4a'] = '<br>Deconectare';
	$_SESSION['nume_pag5a'] = '5a';
	
	$_SESSION['textareacontinut1'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut2'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut3'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut4'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut5'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	
	$_SESSION['textareacontinut1a'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut2a'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut3a'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut4a'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut5a'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	
	$_SESSION['comisie1'] = 'Comisia pentru administratie publica locala, juridic si de disciplina';
	$_SESSION['comisie2'] = 'Comisia buget-finante, administrarea domeniului public si privat';
	$_SESSION['comisie3'] = 'Comisia de servicii publice, munca si protectie sociala';
	$_SESSION['comisie4'] = 'Comisia de invatamant, sanatate, social-culturale, sportive, culte si familie';
	$_SESSION['comisie5'] = 'Comisia de urbanism si amenajarea teritoriului, protectiei  mediului, agricultura si turism';
	
	if($_SESSION['nr_incercari'] == ''){$_SESSION['nr_incercari'] = '0';}
	$_SESSION['nr_incercari_permise'] = '8';
?>
