<?php require_once('admin/setari.php'); 
	include "session.php" 
?>
<?php
	//if($os_win == '1'){
echo '
<!DOCTYPE HTML>
<HTML>
 <HEAD>
 <TITLE></TITLE>
	<META NAME="Keywords" CONTENT="" />
	<META NAME="Description" CONTENT="" />  
	<meta charset="UTF-8">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<META NAME="Generator" CONTENT="NOTEPAD ++">
	<META NAME="Author" CONTENT="stefanfloringr@gmail.com">
	<meta name = "language" content = "ro" /> 
	<meta name = "revisit-after" content = "1 day" /> 
	<meta name = "document-rating" content = "General" />
	<link rel="stylesheet" href="style.css"  type="text/css" media="screen" />	
 </HEAD>
<BODY>
	<table class="all" >
		<tr>
			<td colspan="2" >';
				include "header.php";
		echo'</td>
		</tr>
		<tr>
			<td colspan="2" id="td">';
				include "meniu_orizontal.php";
		echo'</td>
		</tr>
		<tr>
			<td id="stanga">';
				include "continut.php";
		echo'</td>';
		// echo'<!--<td id="dreapta">
				// include "dreapta.php";
			// </td>-->';
	echo'</tr>
		<tr>
			<td id="footer" colspan="2">';
				include "footer.php";
		echo'</td>
		</tr>
	</table> 
</BODY>
</HTML>';
//end index windows
		// }else{
// // start index mobile
// echo '
// <!DOCTYPE HTML>
// <HTML>
 // <HEAD>
 // <TITLE></TITLE>
	// <META NAME="Keywords" CONTENT="" />
	// <META NAME="Description" CONTENT="" />  
	// <meta charset="UTF-8">
	// <meta http-equiv="X-UA-Compatible" content="IE=edge">
	// <meta name="viewport" content="width=device-width, initial-scale=1.0">
	// <META NAME="Generator" CONTENT="NOTEPAD ++">
	// <META NAME="Author" CONTENT="stefanfloringr@gmail.com">
	// <meta name = "language" content = "ro" /> 
	// <meta name = "revisit-after" content = "1 day" /> 
	// <meta name = "document-rating" content = "General" />
	// <link rel="stylesheet" href="style_m.css"  type="text/css" media="screen" />	
 // </HEAD>
// <BODY>
	// <table class="all" >
		// <tr>
			// <td colspan="2" >';
				// include "header_m.php";
		// echo'</td>
		// </tr>
		// <tr>
			// <td colspan="2" id="td">';
				// include "meniu_orizontal_m.php";
		// echo'</td>
		// </tr>
		// <tr>
			// <td id="stanga">
					// <hr>';
				// include "continut_m.php";
		// echo'</td>';
		// // echo'<!--<td id="dreapta">
				// // include "dreapta.php";
			// // </td>-->';
	// echo'</tr>
		// <tr>
			// <td id="footer" colspan="2">';
				// include "footer_m.php";
		// echo'</td>
		// </tr>
	// </table> 
// </BODY>
// </HTML>';
// }
?>
