<?php
if ($_SESSION['login'] == 'da' and $_SESSION['rol'] == 'Cititor' and $_SESSION['status'] == 'Activ'){
echo'
<div id="meniuorizontal">';
// echo'<a href="index.php?pag=1" alt="" title="">
		// <div id="butonmeniu1">'.$_SESSION['nume_pag1'].'</div>
	// </a>';
echo'<a href="index.php?pag=2" alt="" title="">
		<div id="butonmeniu1">'.$_SESSION['nume_pag2'].'</div>
	</a>
	<a href="index.php?pag=3" alt="" title="">
		<div id="butonmeniu1">'.$_SESSION['nume_pag3'].'</div>
	</a>';
	echo'<a href="index.php?pag=4" alt="" title="">
		<div id="butonmeniu1">'.$_SESSION['nume_pag4'].'</div>
	</a>';
// echo'<a href="index.php?pag=5" alt=" title=">
		// <div id="butonmeniu1">'.$_SESSION['nume_pag5'].'</div>
	// </a>';
echo '</div>';
	}
if ($_SESSION['login'] == 'da' and $_SESSION['rol'] == 'Editor' and $_SESSION['status'] == 'Activ'){
echo'
<div id="meniuorizontal">
	<a href="index.php?pag=1b" alt="" title="">
		<div id="butonmeniu">'.$_SESSION['nume_pag1b'].'</div>
	</a>
	<a href="index.php?pag=1a" alt="" title="">
		<div id="butonmeniu">'.$_SESSION['nume_pag1a'].'</div>
	</a>
	<a href="index.php?pag=2a" alt="" title="">
		<div id="butonmeniu">'.$_SESSION['nume_pag2a'].'</div>
	</a>';
// echo'<a href="index.php?pag=3a" alt="" title="">
		// <div id="butonmeniu">'.$_SESSION['nume_pag3a'].'</div>
	// </a>';
echo'<a href="index.php?pag=4a" alt="" title="">
		<div id="butonmeniu">'.$_SESSION['nume_pag4a'].'</div>
	</a>';
	//echo' <a href="index.php?pag=5a" alt=" title=">
		// <div id="butonmeniu">'.$_SESSION['nume_pag5a'].'</div>
	// </a>';
echo '</div>';

}
?>
