body{
	background-color: #FFFFFF;
	background: url(img/bg_.jpg) repeat fixed center top;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: #000000; 
	text-align: left;
}
#dataincarcare {
	text-indent: 20px;
	margin-top:8px; 
	margin-bottom:8px; 
	font-family: arial;
	font-size: 14px;
	text-align: left;
	font-style: italic;
}
#p_center {
	text-indent: 20px;
	margin-top:8px; 
	*margin-bottom:8px; 
	font-family: arial;
	font-size: 14px;
	text-align: center;
	font-style: italic;
}
#p_right {
	text-indent: 20px;
	margin-top:8px; 
	*margin-bottom:8px;
	padding-right:16px;  
	font-family: arial;
	font-size: 14px;
	text-align: right;
	font-style: italic;
}
p {
	text-indent: 20px;
	margin-top:8px; 
	*margin-bottom:8px; 
	font-family: arial;
	font-size: 14px;
	text-align: left;
	font-style: italic;
}
.all{
	width: 1000px; 
	padding: 4px;
	vertical-align:top;
	text-align:left;
	margin-left:auto;
	margin-right:auto; 
	border: solid thin #7D85DA;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
		-webkit-box-shadow: 1px 1px 1px #ffffff; 
		box-shadow: 1px 1px 20px #7D85DA;
}
#header{
	width:100%; 
	height:200px;
	text-align: center;
	vertical-align: middle;
	font-family: Verdana, Courier new, arial;
	font-size: 18px;
	color: #000000; 
	border: solid thin #ffffff;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
		-webkit-box-shadow: 1px 1px 1px #ffffff; 
		box-shadow: 1px 1px 20px #ffffff;
}
#casetaheader{
	width:100%; 
	vertical-align: middle;
}
#headerstanga{
	width:250px; 
	height:200px;
	background-image: url("/img/WebSoft_logo_250x200.jpeg");
	background-position: center;
	background-repeat: no-repeat;
	*background-size: cover;
	*margin-right:10px; 
	text-align: center;
	line-height: 1.5;
	vertical-align: middle;
	*padding: 4px;
	border: solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#headerdreapta{
	height:200px;
	*padding: 8px;
	text-align: center;
	font-family: Verdana, Courier new, arial;
	font-size: 16px;
	*font-weight: bold;
	color: #000000; 
	border: solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#fotoheaderdreapta{
	*width: 500px; 
	height: 180px;
	*padding: 8px;
	text-align:center;
	*border: solid thin #2C5F2D;
	*	-webkit-border-radius: .4em;
	*	-moz-border-radius: .4em;
	*	border-radius: .4em;
	*	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	*	box-shadow: 1px 1px 20px #2C5F2D;
}
#fotoheaderstanga{
	width: 250px; 
	height: 180px;
	*padding: 8px;
	text-align:center;
	border: solid thin #fff;
		-webkit-border-radius: .9em;
		-moz-border-radius: .9em;
		border-radius: .9em;
	*	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	*	box-shadow: 1px 1px 20px #2C5F2D;
}
#meniuorizontal{
	width:80%;
	margin-left:auto; 
	margin-right:auto; 
	*border: solid thin #2C5F2D;
}
#butoaneorizontal{
	width:90%;
	margin-left:auto; 
	margin-right:auto; 
	*border: solid thin #2C5F2D;
}
#butonconfirmare{  
	width:41.5%;
	*height: 40px;
	float: left;
	font-family: arial;
	font-size: 16px;
	text-align: center;
	padding: 15px;
	margin-top: 10px;
	margin-left: 4px;
	margin-bottom: 10px;
	background-color : #F8FFEC;
	border: solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#chenarrosu{
	width : 50%;
	margin-top: 20px;
	margin-left: 25%;
	padding : 20px;
	color : #000000;
	float: left;
	text-align : center;
	background-color : #DF6F7E;
	border : #000000 solid thin;
	border-radius : 0.4em;
}
#butonmeniu{  
	width:18%;
	*height: 40px;
	float: left;
	font-family: arial;
	font-size: 16px;
	text-align: center;
	padding: 15px;
	margin-top: 10px;
	margin-left: 4px;
	margin-bottom: 10px;
	background-color : #F8FFEC;
	border: solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#butonmeniux{  
	width:18%;
	*height: 40px;
	float: left;
	font-family: arial;
	font-size: 16px;
	text-align: center;
	padding: 15px;
	margin-top: 10px;
	margin-left: 4px;
	margin-bottom: 10px;
	background-color : #CAEDFF;
	border: solid thin #000B62;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#butonmeniu1{  
	width:28%;
	*height: 40px;
	float: left;
	font-family: arial;
	font-size: 16px;
	text-align: center;
	padding: 15px;
	margin-top: 10px;
	margin-left: 4px;
	margin-bottom: 10px;
	background-color : #F8FFEC;
	border: solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#butonmeniu1x{  
	width:28%;
	*height: 40px;
	float: left;
	font-family: arial;
	font-size: 16px;
	text-align: center;
	padding: 15px;
	margin-top: 10px;
	margin-left: 4px;
	margin-bottom: 10px;
	background-color : #CAEDFF;
	border: solid thin #000B62;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#butonmeniustanga{  
	width:94%;
	*height: 40px;
	font-family: arial;
	font-size: 16px;
	text-align: left;
	padding-left: 5px;
	padding-right: 5px;
	padding-top: 10px;
	padding-bottom: 10px;
	margin-top: 10px;
	margin-left: 4px;
	margin-bottom: 10px;
	background-color : #F8FFEC;
	border: solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#butonmeniustangax{  
	width:94%;
	*height: 40px;
	font-family: arial;
	font-size: 16px;
	text-align: left;
	padding-left: 5px;
	padding-right: 5px;
	padding-top: 10px;
	padding-bottom: 10px;
	margin-top: 10px;
	margin-left: 4px;
	margin-bottom: 10px;
	background-color : #AEE2FF;
	border: solid thin #000B62;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#butonmeniustanga1{  
	width:90%;
	*height: 40px;
	font-family: arial;
	font-size: 16px;
	text-align: left;
	padding-left: 5px;
	padding-right: 5px;
	padding-top: 10px;
	padding-bottom: 10px;
	margin-top: 10px;
	margin-left: 4px;
	margin-bottom: 10px;
	background-color : #D9ECFF;
	border: solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#butonedit{  
	width:15%;
	*height: 40px;
	font-family: arial;
	font-size: 14px;
	text-align: center;
	padding: 4px;
	margin-top: -39px;
	margin-left: 304px;
	background-color : #F8FFEC;
	border: solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#stanga{
	width:680px; 
	height: 800px;
	padding: 20px;
	vertical-align: top;
	margin-top: 4px;
	line-height: 18px;
	background-color: #FFFFFF;
	*border: solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#numepagina{
	font-family: Verdana, Courier new, arial;
	font-size: 22px;
	font-weight: bold;
	color: #000000; 
}
#dreapta{
	vertical-align: top;
	margin-top: 4px;
	margin-bottom: 4px;
	background-color: #FFFFFF;
	border: solid thin #2C5F2D;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #2C5F2D;
}
#fieldsettot{
	width : 98%;
	margin-top: 20px;
	padding : 5px;
	color : #000000;
	float: left;
	text-align : left;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}

#fieldset30{
	width : 30%;
	margin-top: 20px;
	padding : 5px;
	color : #000000;
	float: left;
	text-align : left;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#fieldsetstanga{
	width : 40%;
	margin-top: 20px;
	padding : 5px;
	color : #000000;
	float: left;
	text-align : left;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#fieldsetdreapta{
	width : 56%;
	margin-top: 20px;
	float: left;
	padding : 5px;
	color : #000000;
	text-align : left;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#fieldsetcautare{
	width : 80%;
	margin-top: 20px;
	margin-left : auto;
	margin-right : auto;
	vertical-align : top;
	padding : 20px;
	color : #000000;
	text-align : center;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#legendcautare {
	padding : 10px;
	margin-left : 1px;
	margin-right : 12px;
	text-align : left;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#inputsave{
	*width: 40%; 
	padding-top: 17px;
	padding-bottom: 17px;
	margin-left:4px;
	text-align:left;
	font-family: Verdana, Courier new, arial;
	*font-size: 14px;
	color: blue; 
	background-color: #9BFF9B;
	border: solid thin #000000;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
}
#inputdel{
	*width: 40%; 
	padding-top: 17px;
	padding-bottom: 17px;
	margin-left:4px;
	text-align:left;
	font-family: Verdana, Courier new, arial;
	*font-size: 14px;
	color: #fff; 
	background-color: #FF7373;
	border: solid thin #000000;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
}
#input40suta{
	width: 39%; 
	padding: 15px;
	margin-top:20px;
	margin-left:4px;
	text-align:left;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: blue; 
	background-color: #F8FFEC;
	border: solid thin #c1c1c1;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
}
#input90suta{
	width: 90%; 
	padding: 15px;
	margin:20px;
	text-align:left;
	font-family: Verdana, Courier new, arial;
	*font-size: 14px;
	color: blue; 
	background-color: #F8FFEC;
	border: solid thin #c1c1c1;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
}
#input100suta{
	width: 94%; 
	padding: 15px;
	margin:20px;
	text-align:left;
	font-family: Verdana, Courier new, arial;
	*font-size: 14px;
	color: blue; 
	background-color: #F8FFEC;
	border: solid thin #c1c1c1;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
}
#butonsubmit{
	padding: 15px;
	margin-left: 4px;
	margin-top: 10px;
	text-align:center;
	font-family: Verdana, Courier new, arial;
	*font-size: 14px;
	color: blue; 
	background-color: #F8FFEC;
	border: solid thin #00000;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
}
#codsecuritate{
	width:60px;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: #000000; 
	padding: 6px;
	text-align: left;
	background-color : #F8FFEC;
	border: solid thin #c1c1c1;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #ffffff;
}
#campdreapta{
	width:220px;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: #000000; 
	padding: 6px;
	text-align: left;
	background-color : #F8FFEC;
	border: solid thin #c1c1c1;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #ffffff;
}
#textareadreapta{
	width:228px;
	height: 200px;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: #000000; 
	text-align: left;
	background-color : #F8FFEC;
	border: solid thin #c1c1c1;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #ffffff;
}
#foto{
width: 670px; 
height: 200px;
padding: 8px;
text-align:center;
*border: solid thin #2C5F2D;
	*-webkit-border-radius: .4em;
	*-moz-border-radius: .4em;
	*border-radius: .4em;
	*-webkit-box-shadow: 1px 1px 1px #ffffff; 
	*box-shadow: 1px 1px 20px #2C5F2D;
}
#footer{
	width:100%; 
	height:40px;
	margin:10px; 
	text-align: center;
	vertical-align: middle;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: #000000; 
	background-color: #FFFFFF;
	border: solid thin #2C5F2D;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #2C5F2D;
}
a:link{
	text-decoration: none;
	color: #000000;
}
a:visited{
	text-decoration: yes;
	color: #000000;
}
a:hover{
	*font-weight: bold;
	text-decoration: yes;
	color: #000000;
	background-color: none;
}
a:active{
	text-decoration: none;
	color: #000000;
}