
<div id="formular">
<br /><br />
<CENTER>Va multumim pentru ca folositi<br />formularul de contact</CENTER>
<br /><br />
<TABLE align="center">
	<form action="" method="post">
		<TR>
			<TD align="left">Nume si prenume :</TD>
		</TR>
		<TR>		
			<TD align="right"><input id="campdreapta" type="text" name="name"></TD>
		</TR>
		<TR>
			<TD align="left">Adresa de email :</TD>
		</TR>
		<TR>		
			<TD align="right"><input id="campdreapta" type="text" name="email"></TD>
		</TR>
		<TR>
			<TD align="left">Nr telefon : </TD>
		</TR>
		<TR>		
			<TD align="right"><input id="campdreapta" type="text" name="phone"></TD>
		</TR>
		<TR>
			<TD align="left">Localitate : </TD>
		</TR>
		<TR>		
			<TD align="right"><input id="campdreapta" type="text" name="oras"></TD>
		</TR>
		<tr>
			<td align="left">Detalii solicitare :</TD>
		</TR>
		<TR>		
			<TD align="right"><textarea id="textareadreapta" name="detalii"></textarea></td>
		</tr> 
		<TR>
			<TD align="left">Cod securitate: 6+2= 
				<input id="codsecuritate" type="text" name="cod_securitate" value=""></TD>
		</TR>
		<TR>
			<TD align="center">Toate campurile sunt obligatorii !</TD>
		</TR>
		<TR>
			<TD align="center"><input id="butonsubmit" type="submit" name="trimite_formular" value="Trimite solicitare"></TD>
		</TR>
	</form>
</TABLE>
</div>
