<?php
session_start(); 
//session_destroy();
 
	$servername ="localhost";
	$dbname ="avicolau_ADICMCL";
	$username ="avicolau_ADICMCL";
	$password ="!Hd]SOK?BOqW";
	$conectare = mysqli_connect($servername, $username, $password, $dbname);
	mysqli_set_charset($conectare,'utf8');


// $ip = "SELECT * FROM `utilizatori` where ip = '".$_SERVER['REMOTE_ADDR']."'";
	// $result_ip = $conn->query($ip);
// if ($result_ip->num_rows > 0) {
	// while($row_ip = $result_ip->fetch_assoc()) {
		// if($row_ip['ip'] != $_SERVER['REMOTE_ADDR']){
			// echo "<script>location.replace('https://bit.ly/2UHWbWr')</script>";
		// }
	// }	
// }

date_default_timezone_set("Europe/Bucharest");
$ymdhis = date("YmdHis");
$data = date("d-m-Y H:i:s");
$dmy = date("Ymj");
$an = date("Y");
$luna = date("m");
$zi = date("d");
//$data = date("Y-m-d");
$prima_zi_luna = date("Y-m-").'01';
$ultima_zi_luna = date("Y-m-").'31';
$title = $_SERVER['SERVER_NAME'];
$adresa_site = "http://".$_SERVER['SERVER_NAME']."/index.php";
$os_win = substr_count($_SERVER['HTTP_USER_AGENT'], 'Windows');
$os_android = substr_count($_SERVER['HTTP_USER_AGENT'], 'Android');
$os_ios = substr_count($_SERVER['HTTP_USER_AGENT'], 'Apple');
$nrcrt = '0';
$limita_afisare_db = '10';
///////////////////////////////////////////////////////////
$ptr_url = array(' ', ',', '+', '/', '\\', '%28', '%29', '(', ')', '"');
/////////////////////////////////////////////////////////////
  
?>
