body{
	background-color: #FFFFFF;
	background: url(img/bg_.jpg) repeat fixed center top;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: #000000; 
	text-align: left;
}
.all{
	width: 100%; 
	padding: 4px;
	vertical-align:top;
	text-align:left;
	margin-left:auto;
	margin-right:auto; 
	border: solid thin #7D85DA;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
		-webkit-box-shadow: 1px 1px 1px #ffffff; 
		box-shadow: 1px 1px 20px #7D85DA;
}
#header{
	width:100%; 
	height:200px;
	text-align: center;
	color: #000000; 
}
#casetaheader{
	width:100%; 
	vertical-align: middle;
}
#headerstanga{
	width:250px; 
	height:200px;
	margin-right:10px; 
	text-align: center;
	line-height: 1.5;
	vertical-align: middle;
	padding: 8px;
	border: solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#headerdreapta{
	height:200px;
	padding: 8px;
	text-align: center;
	font-family: Verdana, Courier new, arial;
	font-size: 16px;
	font-weight: bold;
	color: #000000; 
	border: solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#fotoheader{
	width: 98%; 
	*height: 400px;
	padding: 8px;
	text-align:center;
	border: *solid thin #7D85DA;
		*-webkit-border-radius: .4em;
		*-moz-border-radius: .4em;
		border-radius: .4em;
}
#dataincarcare {
	text-indent: 20px;
	margin-top:8px; 
	margin-bottom:8px; 
	font-family: arial;
	font-size: 14px;
	text-align: left;
	font-style: italic;
}
#p {
	text-indent: 20px;
	margin-top:8px; 
	margin-bottom:8px; 
	font-family: arial;
	font-size: 14px;
	text-align: left;
	font-style: italic;
}
#inputautentificare{
	width:98%;
	font-family: Verdana, Courier new, arial;
	font-size: 44px;
	color: #000000; 
	padding: 6px;
	text-align: center;
	background-color : #F8FFEC;
	border: solid thin #c1c1c1;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #ffffff;
}
@media screen and (min-width: 600px) {
  .all{
    font-size: 80px;
  }
}

@media screen and (max-width: 600px) {
  .all{
    font-size: 30px;
  }
}

a:link{
	text-decoration: none;
	color: #000000;
}
a:visited{
	text-decoration: none;
	color: blue;
}
a:hover{
	color: #000000;
	background-color: none;
}
a:active{
	text-decoration: none;
	color: blue;
}