<?php
//echo $_SESSION['login'];
//echo $username;
if ($_SESSION['login'] == '')
		{include "autentificare.php";}
if ($_SESSION['login'] == 'da' and $_SESSION['rol'] == 'Cititor' and $_SESSION['status'] == 'Activ'){

if ($_GET["pag"] == "" or $_GET["pag"] == "1"){
		echo '<br />
	<fieldset id="fieldsetcautare">
	<legend id="legendcautare" align="left">Material informativ</legend>';
	
	echo '</fieldset>';		
			}
if ($_GET["pag"] == "2" and $_GET['id_doc'] == ''){
	echo '<fieldset id="fieldsetstanga">
	<legend id="legendcautare" align="left">Alege sedinta</legend>';
	$sedinta = "SELECT * FROM `sedinta` order by id desc limit ".$limita_afisare_db."";
		$result_sed = $conectare->query($sedinta);
		while($row_sed = $result_sed->fetch_assoc()) {
			echo'<a href="index.php?pag=2&id_sedinta='.$row_sed['id'].'" title="Incarcat la data '.substr($row_sed['data'],6,2 ).'-'.substr($row_sed['data'],4,2 ).'-'.substr($row_sed['data'],0,4 ).'">
					<div id="butonmeniustanga">'.$row_sed['nume_sedinta'].'
						<p id="dataincarcare">(Incarcat la data: '.substr($row_sed['data'],6,2 ).'-'.substr($row_sed['data'],4,2 ).'-'.substr($row_sed['data'],0,4 ).' '.substr($row_sed['data'],8,2 ).':'.substr($row_sed['data'],10,2 ).':'.substr($row_sed['data'],12,2 ).')</p>
					</div>
				</a>';	
		} 
	echo'<BR />
	</fieldset>';	
		
		$materiale = "SELECT * FROM `materiale` WHERE id_sedinta = '".$_GET['id_sedinta']."' order by nume_proiect asc";
		$result_mat = $conectare->query($materiale);
		if($_GET['id_sedinta'] !=''){
			echo '<fieldset id="fieldsetdreapta">
				<legend id="legendcautare" align="left">Proiectele sedintei</legend>';
		while($row_mat = $result_mat->fetch_assoc()) {

			echo'<a href="index.php?pag=2&id_doc='.$row_mat['id'].'" title="Incarcat la data '.substr($row_mat['data'],6,2 ).'-'.substr($row_mat['data'],4,2 ).'-'.substr($row_mat['data'],0,4 ).'">
					<div id="butonmeniustanga">'.$row_mat['nume_proiect'].'
						<p id="dataincarcare">(Incarcat la data: '.substr($row_mat['data'],6,2 ).'-'.substr($row_mat['data'],4,2 ).'-'.substr($row_mat['data'],0,4 ).' '.substr($row_mat['data'],8,2 ).':'.substr($row_mat['data'],10,2 ).':'.substr($row_mat['data'],12,2 ).')</p>
					</div>
				</a>';	
		}
		echo'<BR />
	</fieldset>';
	}
	
}
if ($_GET["pag"] == "2" and $_GET['id_doc'] != ''){
	echo '<fieldset id="fieldsettot">
	<a href="'.$_SERVER['HTTP_REFERER'].'">
		<legend id="butonmeniu" align="left">
			Inapoi
		</legend>
	</a>';
	$materiale = "SELECT * FROM `materiale` WHERE id = '".$_GET['id_doc']."'";
		$result_mat = $conectare->query($materiale);
		while($row_mat = $result_mat->fetch_assoc()) {
			echo'<embed src='.$row_mat['link'].' type="application/pdf" width="100%" height="1000px" />';
		}
	echo'<BR />
	</fieldset>';	
}
if ($_GET["pag"] == "3" and $_GET['id_doc'] == ''){
	echo '<fieldset id="fieldset30">
	<legend id="legendcautare" align="left">Alege sedinta</legend>';
	$sedinta = "SELECT * FROM `sedinta` order by id desc limit ".$limita_afisare_db."";
		$result_sed = $conectare->query($sedinta);
		//$nr_inreg=mysqli_num_rows($result_sed);
		while($row_sed = $result_sed->fetch_assoc()) {
			
			echo'<a href="index.php?pag=3&id_sedinta='.$row_sed['id'].'" title="Incarcat la data '.substr($row_sed['data'],6,2 ).'-'.substr($row_sed['data'],4,2 ).'-'.substr($row_sed['data'],0,4 ).'">
					<div id="butonmeniustanga">'.$row_sed['nume_sedinta'].'
						<p id="dataincarcare">(Incarcat la: '.substr($row_sed['data'],6,2 ).'-'.substr($row_sed['data'],4,2 ).'-'.substr($row_sed['data'],0,4 ).' '.substr($row_sed['data'],8,2 ).':'.substr($row_sed['data'],10,2 ).':'.substr($row_sed['data'],12,2 ).')</p>
					</div>
				</a>';	
		} 
	echo'<BR />
	</fieldset>';	
		
		if($_GET['id_sedinta'] !=''){
			echo '<fieldset id="fieldset30">
	<legend id="legendcautare" align="left">Alege comisie</legend>';
echo'<a href="index.php?pag=3&id_sedinta='.$_GET['id_sedinta'].'&id_comisie=1"><div id="butonmeniustanga">'.$_SESSION['comisie1'].'</div></a>';
echo'<a href="index.php?pag=3&id_sedinta='.$_GET['id_sedinta'].'&id_comisie=2"><div id="butonmeniustanga">'.$_SESSION['comisie2'].'</div></a>';
echo'<a href="index.php?pag=3&id_sedinta='.$_GET['id_sedinta'].'&id_comisie=3"><div id="butonmeniustanga">'.$_SESSION['comisie3'].'</div></a>';
echo'<a href="index.php?pag=3&id_sedinta='.$_GET['id_sedinta'].'&id_comisie=4"><div id="butonmeniustanga">'.$_SESSION['comisie4'].'</div></a>';
echo'<a href="index.php?pag=3&id_sedinta='.$_GET['id_sedinta'].'&id_comisie=5"><div id="butonmeniustanga">'.$_SESSION['comisie5'].'</div></a>';
echo'<BR />
	</fieldset>';
	}
if($_GET['id_sedinta'] !='' and $_GET['id_comisie'] !=''){	
	echo '<fieldset id="fieldset30">
	<legend id="legendcautare" align="left">Proiectele sedintei/comisiei</legend>';
		$materiale = "SELECT * FROM `materiale` WHERE id_sedinta = '".$_GET['id_sedinta']."' and id_comisie like '%".$_GET['id_comisie']."%' order by nume_proiect asc";
		$result_mat = $conectare->query($materiale);
		if ($result_mat->num_rows != 0) {
		while($row_mat = $result_mat->fetch_assoc()) {
			if($os_win == '1'){
			echo'<a href="index.php?pag=3&id_doc='.$row_mat['id'].'" title="Incarcat la data '.substr($row_mat['data'],6,2 ).'-'.substr($row_mat['data'],4,2 ).'-'.substr($row_mat['data'],0,4 ).'">
					<div id="butonmeniustanga">'.$row_mat['nume_proiect'].'
						<p id="dataincarcare">(Incarcat la: '.substr($row_mat['data'],6,2 ).'-'.substr($row_mat['data'],4,2 ).'-'.substr($row_mat['data'],0,4 ).' '.substr($row_mat['data'],8,2 ).':'.substr($row_mat['data'],10,2 ).':'.substr($row_mat['data'],12,2 ).')</p>
					</div>
				</a>';
			}else{
			echo'<a href="'.$row_mat['link'].'" target ="_blank" title="Incarcat la data '.substr($row_mat['data'],6,2 ).'-'.substr($row_mat['data'],4,2 ).'-'.substr($row_mat['data'],0,4 ).'">
					<div id="butonmeniustanga">'.$row_mat['nume_proiect'].'
						<p id="dataincarcare">(Incarcat la: '.substr($row_mat['data'],6,2 ).'-'.substr($row_mat['data'],4,2 ).'-'.substr($row_mat['data'],0,4 ).' '.substr($row_mat['data'],8,2 ).':'.substr($row_mat['data'],10,2 ).':'.substr($row_mat['data'],12,2 ).')</p>
					</div>
				</a>';	
			}
		}
		echo'<BR />
	</fieldset>';
		}else{
	echo '<div id="butonmeniustanga">Nu exista proiecte pentru aceasta sedinta/comisie.</div>';
	}
	}
}
if ($_GET["pag"] == "3" and $_GET['id_doc'] != ''){
	echo '<fieldset id="fieldsettot">
	<a href="'.$_SERVER['HTTP_REFERER'].'">
		<legend id="butonmeniu" align="left">
			Inapoi
		</legend>
	</a>';
	$materiale = "SELECT * FROM `materiale` WHERE id = '".$_GET['id_doc']."'";
		$result_mat = $conectare->query($materiale);
		while($row_mat = $result_mat->fetch_assoc()) {
			echo'<embed src='.$row_mat['link'].' type="application/pdf" width="100%" height="1100px" />';
		}
	echo'<BR />
	</fieldset>';	
}
if ($_GET["pag"] == "4"){
	session_destroy();
	echo"<script>location.replace('index.php')</script>";
			}
if ($_GET["pag"] == "5"){
	echo'<p id="numepagina">'.$_SESSION['nume_pag5'].'</p>
		<br />
	<p>'.$_SESSION['textareacontinut5'].'</p>';
}
	}
	
if ($_SESSION['login'] == 'da' and $_SESSION['rol'] == 'Editor' and $_SESSION['status'] == 'Activ'){
//start adauga nume sedinta
if($_POST['add_sedinta']){

	$data_sedinta1 = explode('-', $_POST['data_sedinta']);
	$data_sedinta = ($data_sedinta1['2'].'.'.$data_sedinta1['1'].'.'.$data_sedinta1['0']);
	$nume_sedinta = ($_POST['nume_sedinta']);
	$tip_sedinta = $_POST['tip_sedinta'];
	
	$adauga_sedinta = ("INSERT INTO `sedinta`(`data`, `nume_sedinta`, `data_sedinta`, `user`) VALUES ('".$ymdhis."', '".$nume_sedinta."', '".$data_sedinta."', '".$_SESSION['nume_utilizator']."')") or die(mysql_error());
	
	if (mysqli_query($conectare, $adauga_sedinta)) {
		echo "<script>alert('Nume sedinta adaugat cu SUCCES.')</script>";
			if($tip_sedinta == 'SCL'){
				echo"<script>location.replace('index.php?pag=2a')</script>";
			}
			if($tip_sedinta == 'SCS'){
				echo"<script>location.replace('index.php?pag=3a')</script>";
			}
	}else{
		echo "<script>alert('EROARE la adaugare')</script>";
	}
}
// end adauga nume sedinta
//start adauga materiale SCL
if($_POST['add_materiale_SCL']){
	//echo $suma_control;
	if($suma_control == '0'){
		echo "<script>alert('Trebuie sa alegi cel putin una comisie.')</script>";
	}else{
	$nume_proiect = $_POST['nume_proiect'];
	$suma_control = ($_POST['id_comisie1']+$_POST['id_comisie2']+$_POST['id_comisie3']+$_POST['id_comisie4']+$_POST['id_comisie5']);
	$id_comisie = ($_POST['id_comisie1'].'-'.$_POST['id_comisie2'].'-'.$_POST['id_comisie3'].'-'.$_POST['id_comisie4'].'-'.$_POST['id_comisie5']);
	$nume_sedinta = $_POST['nume_sedinta'];
	$id_sedinta = $_POST['id_sedinta'];
	$tip_doc = $_POST['tip_doc'];
	
		$file_size=$_FILES["file"]["size"];
		$file_name=$_FILES["file"]["name"];
		$redenumire = $ymdhis.'.pdf';
		$temp_name=$_FILES["file"]["tmp_name"];
		$file_type=$_FILES["file"]["type"];
		$upload='upload/';
		// $filename = strrev($file_name);
		// $filename_ext = substr($filename, 0,4);

		if($file_type == 'application/pdf'){
		move_uploaded_file($temp_name,$upload.''.$redenumire);

	$link = $upload.''.$redenumire;
	
	$adauga_materiale = ("INSERT INTO `materiale`(`data`, `id_sedinta`, `nume_sedinta`, `tip_doc`, `user`, `link`, `id_comisie`, `nume_proiect`) VALUES ('".$ymdhis."', '".$id_sedinta."', '".$nume_sedinta."', '".$tip_doc."', '".$_SESSION['nume_utilizator']."', '".$link."', '".$id_comisie."', '".$nume_proiect."')") or die(mysql_error());
		}else{
			echo "<script>alert('Sunt acceptate doar fisiere cu extensia pdf.')</script>";
		}
	if (mysqli_query($conectare, $adauga_materiale)) {
		echo "<script>alert('Document adaugat cu SUCCES.')</script>";
	}else{
		echo "<script>alert('EROARE la adaugare')</script>";
	}	
}
}
//end adauga materiale SCL
//start adauga materiale SCS
// if($_POST['add_materiale_SCS']){
	
	// $nume_sedinta = $_POST['nume_sedinta'];
	// $id_sedinta = $_POST['id_sedinta'];
	// $tip_sedinta = 'SCS';
	
		// $file_size=$_FILES["file"]["size"];
		// $file_name=$_FILES["file"]["name"];
		// $redenumire = $ymdhis.'.pdf';
		// $temp_name=$_FILES["file"]["tmp_name"];
		// $file_type=$_FILES["file"]["type"];
		// $upload='upload/';
		
		// if($file_type == 'application/pdf'){
		// move_uploaded_file($temp_name,$upload.''.$redenumire);
		// // echo "Original file name: ".$file_name."<br>";
		// // echo "Redenumire: ".$redenumire."<br>";
		// // echo "File name after upload: ".$temp_name."<br>";
		// // echo "File size: ".$file_size."<br>";
		// // echo "File type: ".$file_type;

	// $link = $upload.''.$redenumire;
	
	// $adauga_materiale = ("INSERT INTO `materiale`(`data`, `id_sedinta`, `nume_sedinta`, `tip_sedinta`, `user`, `link`) VALUES ('".$ymdhis."', '".$id_sedinta."', '".$nume_sedinta."', '".$tip_sedinta."', '".$_SESSION['nume_utilizator']."', '".$link."')") or die(mysql_error());
		// }else{
			// echo "<script>alert('Sunt acceptate doar fisiere cu extensia pdf.')</script>";
		// }
	// if (mysqli_query($conectare, $adauga_materiale)) {
		// echo "<script>alert('Document adaugat cu SUCCES.')</script>";
	// }else{
		// echo "<script>alert('EROARE la adaugare')</script>";
	// }	
// }
//end adauga materiale SCS

//// START modul editor ////

if ($_GET["pag"] == "1a"){
	//echo'<p id="numepagina">'.$_SESSION['nume_pag1a'].'</p>';

	echo '<br />
<form method="post" action="" autocomplete="off">
	<fieldset id="fieldsetcautare">
	<legend id="legendcautare" align="left">Adauga sedinta noua</legend>
		<input id="input90suta" name="nume_sedinta" type="text" required value="" placeholder="Denumire Sedinta">
		<BR />
		<input id="input40suta" name="data_sedinta" type="date" required value="" >
		<BR />
		<input id="butonsubmit" name="add_sedinta" type="submit" value="Salveaza denumire sedinta" >
	</fieldset>
</form>';
}
if($_POST['an_sedinta']){
		$_SESSION['an_sedinta'] = $_POST['an_sedinta'];
	}else{
		$_SESSION['an_sedinta'] = $_SESSION['an_sedinta'];
	}
if($_POST['reset_an']){
		unset ($_SESSION['an_sedinta']);
}

if ($_GET["pag"] == "1b" and $_GET['id_doc'] == ''){
	echo '<fieldset id="fieldsettot">
	<legend id="legendcautare" align="left">Cauta sedinte dupa An <b>'.$_SESSION['an_sedinta'].'</b></legend>
		<form method="POST" action="index.php?pag=1b" autocomplete="off">
			<input id="input40suta" name="an_sedinta" type="number" min="2020" value="" >
			<input id="butonsubmit" name="cauta_sedinta" type="submit" value="Cauta sedinte" >
			<input id="butonsubmit" name="reset_an" type="submit" value="Reset" >
		</form>
		<BR />
	</fieldset>';	
	if($_GET["edit"] == ""){
	echo '<fieldset id="fieldsetstanga">
	<legend id="legendcautare" align="left">Alege sedinta</legend>';
	if($_SESSION['an_sedinta'] != ''){
			$sedinta = "SELECT * FROM `sedinta` where data like '%".$_SESSION['an_sedinta']."%' order by id desc";
		}else{
			$sedinta = "SELECT * FROM `sedinta` order by id desc limit ".$limita_afisare_db."";
		}
		$result_sed = $conectare->query($sedinta);
		while($row_sed = $result_sed->fetch_assoc()) {
			echo'<a href="index.php?pag=1b&id_sedinta='.$row_sed['id'].'" title="Incarcat la data '.substr($row_sed['data'],6,2 ).'-'.substr($row_sed['data'],4,2 ).'-'.substr($row_sed['data'],0,4 ).'">
					<div id="butonmeniustanga">'.$row_sed['nume_sedinta'].' '.$row_sed['data_sedinta'].'
						<p id="dataincarcare">(Incarcat la data: '.substr($row_sed['data'],6,2 ).'-'.substr($row_sed['data'],4,2 ).'-'.substr($row_sed['data'],0,4 ).' '.substr($row_sed['data'],8,2 ).':'.substr($row_sed['data'],10,2 ).':'.substr($row_sed['data'],12,2 ).')</p>
					</div>
				</a>
				<a href="index.php?pag=1b&id_sedinta='.$row_sed['id'].'&edit=da">
					<p id="butonedit">Edit</p>
				</a>';	
		} 
	echo'<BR />
	</fieldset>
	<BR />';	
		
		$materiale1 = "SELECT * FROM `materiale` WHERE id_sedinta = '".$_GET['id_sedinta']."' order by nume_proiect asc";
			$result_mat1 = $conectare->query($materiale1);
		if($_GET['id_sedinta'] !=''){
			while($row_mat1 = $result_mat1->fetch_assoc()) {
				$nume_sedinta = $row_mat1['nume_sedinta'];
				}
			echo '<fieldset id="fieldsetdreapta">
					<legend id="legendcautare" align="left">'.$nume_sedinta.'</legend>';	
		$materiale = "SELECT * FROM `materiale` WHERE id_sedinta = '".$_GET['id_sedinta']."' order by nume_proiect asc";
			$result_mat = $conectare->query($materiale);					
		while($row_mat = $result_mat->fetch_assoc()) {
			echo'<a href="index.php?pag=1b&id_doc='.$row_mat['id'].'" title="Incarcat la data '.substr($row_mat['data'],6,2 ).'-'.substr($row_mat['data'],4,2 ).'-'.substr($row_mat['data'],0,4 ).'">
					<div id="butonmeniustanga">'.$row_mat['nume_proiect'].'
						<p id="dataincarcare">(Incarcat la data: '.substr($row_mat['data'],6,2 ).'-'.substr($row_mat['data'],4,2 ).'-'.substr($row_mat['data'],0,4 ).' '.substr($row_mat['data'],8,2 ).':'.substr($row_mat['data'],10,2 ).':'.substr($row_mat['data'],12,2 ).')</p>
					</div>
				</a>';
			
		}
	echo'<BR />
	</fieldset>';	
	}else{
		echo '<fieldset id="fieldsetdreapta">
					<legend id="legendcautare" align="left">Proiectele sedintei</legend>
					
					<BR />
				</fieldset>';	
		}
	}
}

if ($_GET["pag"] == "1b" and $_GET['id_doc'] != ''){
	echo '<fieldset id="fieldsettot">
	<a href="'.$_SERVER['HTTP_REFERER'].'">
		<legend id="butonmeniu" align="left">
			Inapoi
		</legend>
	</a>';
	$materiale = "SELECT * FROM `materiale` WHERE id = '".$_GET['id_doc']."'";
		$result_mat = $conectare->query($materiale);
		while($row_mat = $result_mat->fetch_assoc()) {
			echo'<embed src='.$row_mat['link'].' type="application/pdf" width="100%" height="1000px" />';
		}
	echo'<BR />
	</fieldset>';	
}
if($_POST['salveaza_modificari_nume']){
		$data_sedinta1 = explode('-', $_POST['data_sedinta']);
		$data_sedinta = ($data_sedinta1['2'].'-'.$data_sedinta1['1'].'-'.$data_sedinta1['0']);	
	$sql = ("UPDATE `sedinta` SET `data` = '".$ymdhis."', `nume_sedinta` = '".$_POST['nume_sedinta']."', `data_sedinta` = '".$data_sedinta."', `user` = '".$_SESSION['nume_utilizator']."' where id = '".$_GET['id_sedinta']."'") or die(mysql_error());
		if (mysqli_query($conectare, $sql)) {
			echo "<script>alert('Document MODIFICAT cu SUCCES.')</script>";
		}else{
			echo "<script>alert('EROARE la adaugare')</script>";
		}
}
if($_POST['salveaza_modificari_doc']){
	
	if($_POST['tip_doc'] == 'ODZ' ){$nume_proiect = ' Ordine de zi';}
	if($_POST['tip_doc'] == 'PV' ){$nume_proiect = ' Proces Verbal';}
	if($_POST['tip_doc'] == 'PROI' ){$nume_proiect = trim($_POST['nume_proiect']);}
		$file_size=$_FILES["file"]["size"];
		$file_name=$_FILES["file"]["name"];
		$redenumire = $ymdhis.'.pdf';
		$temp_name=$_FILES["file"]["tmp_name"];
		$file_type=$_FILES["file"]["type"];
		$upload='upload/';

		if($file_type == 'application/pdf'){
		move_uploaded_file($temp_name,$upload.''.$redenumire);

	$link = $upload.''.$redenumire;
	
	$sql = ("UPDATE `materiale` SET `data` = '".$ymdhis."', `tip_doc` = '".$_POST['tip_doc']."', `user` = '".$_SESSION['nume_utilizator']."', `link` = '".$link."', `nume_proiect` = '".$nume_proiect."' where id = '".$_POST['id_mat']."'") or die(mysql_error());
		}else{

			echo "<script>alert('Sunt acceptate doar fisiere cu extensia pdf.')</script>";
			echo "<script>location.replace('".$_SERVER['HTTP_REFERER']."')</script>";
		}
		if (mysqli_query($conectare, $sql)) {
			echo "<script>alert('Document MODIFICAT cu SUCCES.')</script>";
			echo "<script>location.replace('".$_SERVER['HTTP_REFERER']."')</script>";
		}else{
			echo "<script>alert('EROARE la adaugare')</script>";
			echo "<script>location.replace('".$_SERVER['HTTP_REFERER']."')</script>";
	}
}
if($_POST['sterge_sedinta']){
	echo'<div id="chenarrosu">
			Esti sigur ca vrei sa ELIMINI definitiv aceasta sedinta ?
				<a href="index.php?pag=1b&id_sedinta='.$_GET['id_sedinta'].'&edit=da&confirmare=da"><div id="butonconfirmare">DA</div></a>
				<a href="'.$_SERVER['HTTP_REFERER'].'"><div id="butonconfirmare">NU</div></a>
		</div>';
}
if($_GET['confirmare'] == 'da'){	
		
	$sql_sed = ("DELETE FROM `sedinta` WHERE `id` = '".$_GET['id_sedinta']."'");
	$sql_doc = ("DELETE FROM `materiale` WHERE `id_sedinta` = '".$_GET['id_sedinta']."'");
		if (mysqli_query($conectare, $sql_sed)) {
			echo "<script>alert('SEDINTA ELIMINATA CU SUCCES.')</script>";
			echo "<script>location.replace('index.php?pag=1b')</script>";
		}
		if (mysqli_query($conectare, $sql_doc)) {
			echo "<script>alert('SEDINTA ELIMINATA CU SUCCES.')</script>";
			echo "<script>location.replace('index.php?pag=1b')</script>";
		
	}
}
if($_GET["edit"] == "da"){
	$sedinta = "SELECT * FROM `sedinta` where id = ".$_GET["id_sedinta"]."";
		$result_sed = $conectare->query($sedinta);
		while($row_sed = $result_sed->fetch_assoc()) {
			$data_sedinta1 = explode('-', $row_sed['data_sedinta']);
			$data_sedinta = ($data_sedinta1['2'].'-'.$data_sedinta1['1'].'-'.$data_sedinta1['0']);
	echo '<fieldset id="fieldsettot">
	<legend id="legendcautare" align="left">Editeaza sedinta</legend>
		<form method="POST" action="index.php?pag=1b&id_sedinta='.$row_sed['id'].'&edit=da" autocomplete="off">
			<input id="input40suta" name="nume_sedinta" type="text" required value="'.$row_sed['nume_sedinta'].'" >
			<input id="input40suta" name="data_sedinta" type="date" required value="'.date($data_sedinta).'" >
			<input id="inputsave" name="salveaza_modificari_nume" type="submit" value="Save" >
		</form>';
		}
	$materiale = "SELECT * FROM `materiale` WHERE id_sedinta = '".$_GET['id_sedinta']."' order by nume_proiect asc";
		$result_mat = $conectare->query($materiale);
		while($row_mat = $result_mat->fetch_assoc()) {
		echo'<form method="POST" action="'.$_SERVER['HTTP_REFERER'].'" enctype="multipart/form-data" autocomplete="off">
				<input id="input40suta" name="nume_proiect" type="text" required value="'.$row_mat['nume_proiect'].'" placeholder="Nume Proiect">
				 <input id="input40suta" name="file" type="file" accept="application/pdf" required value="" placeholder="Incarca documentul." title="">
				 <input name="id_mat" type="hidden" value="'.$row_mat['id'].'">
				 <input name="tip_doc" type="hidden" value="'.$row_mat['tip_doc'].'">
				 <input id="inputsave" name="salveaza_modificari_doc" type="submit" value="Save" >
			</form>';
		}
		echo '<form method="POST" action="index.php?pag=1b&id_sedinta='.$_GET['id_sedinta'].'&edit=da" autocomplete="off">
			<input id="butonsubmit" name="sterge_sedinta" type="submit" value="Sterge sedinta" >
		</form>
		<BR />
	</fieldset>';	
}
if ($_GET["pag"] == "2a"){
	//echo'<p id="numepagina">'.$_SESSION['nume_pag2a'].'</p>';
		echo'<br />
<form method="post" action=""  enctype="multipart/form-data" autocomplete="off">
	<fieldset id="fieldsetcautare">
	<legend id="legendcautare" align="left">Adauga materiale la sedinta SCL</legend>';
	echo'<select name="id_sedinta" id="input100suta" onchange="submit()" required >';
	echo'<option value="">Alege sedinta</option>';
	$sedinta = "SELECT * FROM `sedinta` order by id desc limit ".$limita_afisare_db."";
		$result_sed = $conectare->query($sedinta);
		while($row_sed = $result_sed->fetch_assoc()) {
				$selected = $selected.''.$row_sed['id'];
			if($row_sed['id'] == $_POST['id_sedinta']){$selected = 'selected'; $nume_sedinta = $row_sed['nume_sedinta'];}
			echo'<option '.$selected.' value="'.$row_sed['id'].'">'.$row_sed['nume_sedinta'].'</option>';
		} 
	echo'</select>';	
		if($_POST['tip_doc'] == 'PROI'){$checked1 = 'checked';}
		if($_POST['tip_doc'] == 'ODZ'){$checked2 = 'checked';}
		if($_POST['tip_doc'] == 'PV'){$checked3 = 'checked';}
	echo'<input id="" name="tip_doc" value="PROI" type="radio" '.$checked1.' required onchange="submit()">Proiect
		<input id="" name="tip_doc" value="ODZ" type="radio" '.$checked2.' required onchange="submit()">Ordine de zi
		<input id="" name="tip_doc" value="PV" type="radio" '.$checked3.' required onchange="submit()">Proces Verbal
		<BR />';
		if($_POST['tip_doc'] == 'PROI'){
	echo'<input id="input90suta" name="nume_proiect" type="text" required value="" placeholder="Nume Proiect">
	<BR />
		<p><input id="" name="id_comisie1" value="1" type="checkbox" >'.$_SESSION['comisie1'].'</p>
		<p><input id="" name="id_comisie2" value="2" type="checkbox" >'.$_SESSION['comisie2'].'</p>
		<p><input id="" name="id_comisie3" value="3" type="checkbox" >'.$_SESSION['comisie3'].'</p>
		<p><input id="" name="id_comisie4" value="4" type="checkbox" >'.$_SESSION['comisie4'].'</p>
		<p><input id="" name="id_comisie5" value="5" type="checkbox" >'.$_SESSION['comisie5'].'</p>';
		}
	if($_POST['tip_doc'] == 'ODZ'){
	echo'<input id="input90suta" name="nume_proiect" type="hidden" required value=" Ordine de zi" placeholder=" Ordine de zi" readonly>
	<BR />
		<p><input id="" name="id_comisie1" value="1" type="checkbox" checked>'.$_SESSION['comisie1'].'</p>
		<p><input id="" name="id_comisie2" value="2" type="checkbox" checked>'.$_SESSION['comisie2'].'</p>
		<p><input id="" name="id_comisie3" value="3" type="checkbox" checked>'.$_SESSION['comisie3'].'</p>
		<p><input id="" name="id_comisie4" value="4" type="checkbox" checked>'.$_SESSION['comisie4'].'</p>
		<p><input id="" name="id_comisie5" value="5" type="checkbox" checked>'.$_SESSION['comisie5'].'</p>';		
		}
	if($_POST['tip_doc'] == 'PV'){
	echo'<input id="input90suta" name="nume_proiect" type="hidden" required value=" Proces Verbal" placeholder=" Proces Verbal" readonly>
	<BR />
		<p><input id="" name="id_comisie1" value="1" type="checkbox" checked>'.$_SESSION['comisie1'].'</p>
		<p><input id="" name="id_comisie2" value="2" type="checkbox" checked>'.$_SESSION['comisie2'].'</p>
		<p><input id="" name="id_comisie3" value="3" type="checkbox" checked>'.$_SESSION['comisie3'].'</p>
		<p><input id="" name="id_comisie4" value="4" type="checkbox" checked>'.$_SESSION['comisie4'].'</p>
		<p><input id="" name="id_comisie5" value="5" type="checkbox" checked>'.$_SESSION['comisie5'].'</p>';		
		}
	if($_POST['tip_doc'] != ''){
	echo'<input id="input90suta" name="file" type="file" accept="application/pdf" required value="" placeholder="Incarca documentul." title="">
		<input name="nume_sedinta" type="hidden" value="'.$nume_sedinta.'">
		<BR />
		<input id="butonsubmit" name="add_materiale_SCL" type="submit" value="Salveaza materiale sedinta" >';
	}
	echo'</fieldset>
</form>';
}
// if ($_GET["pag"] == "3a"){
	// //echo'<p id="numepagina">'.$_SESSION['nume_pag3a'].'</p>';
	// echo'<br />
// <form method="post" action=""  enctype="multipart/form-data" autocomplete="off">
	// <fieldset id="fieldsetcautare">
	// <legend id="legendcautare" align="left">Adauga materiale la sedinta SCS</legend>';
	// echo'<select name="id_sedinta" id="input100suta" onchange="submit()" required>';
	// echo'<option value="">Alege sedinta SCS</option>';
	// $sedinta = "SELECT * FROM `sedinta` WHERE tip_sedinta = 'SCS' order by id desc limit ".$limita_afisare_db."";
		// $result_sed = $conectare->query($sedinta);
		// while($row_sed = $result_sed->fetch_assoc()) {
				// $selected = $selected.''.$row_sed['id'];
			// if($row_sed['id'] == $_POST['id_sedinta']){$selected = 'selected'; $nume_sedinta = $row_sed['nume_sedinta'];}
			// echo'<option '.$selected.' value="'.$row_sed['id'].'">'.$row_sed['nume_sedinta'].'</option>';
		// } 
	// echo'</select>	
		// <input id="input90suta" name="file" type="file" accept="application/pdf" required value="" placeholder="Incarca documentul." title="">
		// <input name="nume_sedinta" type="hidden" value="'.$nume_sedinta.'">
		// <BR />
		// <input id="butonsubmit" name="add_materiale_SCS" type="submit" value="Salveaza materiale sedinta" >
	// </fieldset>
// </form>';
// }
if ($_GET["pag"] == "4a"){
	session_destroy();
	echo"<script>location.replace('index.php')</script>";
}
if ($_GET["pag"] == "5a"){
	echo'<p id="numepagina">'.$_SESSION['nume_pag5a'].'</p>
		<br />
	<p>'.$_SESSION['textareacontinut5a'].'</p>';
	}

}
if ($_GET["pag"] == "4a"){
	session_destroy();
	echo"<script>location.replace('index.php')</script>";
}
?>
