<?php
if ($_SESSION['login'] == 'da' and $_SESSION['rol'] == 'Cititor' and $_SESSION['status'] == 'Activ'){
	if($_GET['pag'] == '1'){$id_style1 = 'id="butonmeniu1x"';}else{$id_style1 = 'id="butonmeniu1"';}
	if($_GET['pag'] == '2'){$id_style2 = 'id="butonmeniu1x"';}else{$id_style2 = 'id="butonmeniu1"';}
	if($_GET['pag'] == '3'){$id_style3 = 'id="butonmeniu1x"';}else{$id_style3 = 'id="butonmeniu1"';}
	if($_GET['pag'] == '4'){$id_style4 = 'id="butonmeniu1x"';}else{$id_style4 = 'id="butonmeniu1"';}
	if($_GET['pag'] == '5'){$id_style5 = 'id="butonmeniu1x"';}else{$id_style5 = 'id="butonmeniu1"';}
	
echo'
<div id="meniuorizontal">
	<div id="butoaneorizontal">';
// echo'<a href="index.php?pag=1" alt="" title="">
		// <div id="butonmeniu1">'.$_SESSION['nume_pag1'].'</div>
	// </a>';
echo'<a href="index.php?pag=2" alt="" title="">
		<div '.$id_style2.'>'.$_SESSION['nume_pag2'].'</div>
	</a>';
	//echo '<h2 id="C1"></h2>';
	echo'<a href="index.php?pag=3" alt="" title="">
		<div '.$id_style3.'>'.$_SESSION['nume_pag3'].'</div>
	</a>';
	
	//echo '<h2 id="C2"></h2>';
	echo'<a href="index.php?pag=4" alt="" title="">
		<div '.$id_style4.'>'.$_SESSION['nume_pag4'].'</div>
	</a>';
	
// echo'<a href="index.php?pag=5" alt=" title=">
		// <div '.$id_style5.'>'.$_SESSION['nume_pag5'].'</div>
	// </a>';
echo '</div>';
echo '</div>';
	}
if ($_SESSION['login'] == 'da' and $_SESSION['rol'] == 'Editor' and $_SESSION['status'] == 'Activ'){
	if($_GET['pag'] == '1a'){$id_style1a = 'id="butonmeniux"';}else{$id_style1a = 'id="butonmeniu"';}
	if($_GET['pag'] == '1b'){$id_style1b = 'id="butonmeniux"';}else{$id_style1b = 'id="butonmeniu"';}
	if($_GET['pag'] == '2a'){$id_style2a = 'id="butonmeniux"';}else{$id_style2a = 'id="butonmeniu"';}
	if($_GET['pag'] == '3a'){$id_style3a = 'id="butonmeniux"';}else{$id_style3a = 'id="butonmeniu"';}
	if($_GET['pag'] == '4a'){$id_style4a = 'id="butonmeniux"';}else{$id_style4a = 'id="butonmeniu"';}
	if($_GET['pag'] == '5a'){$id_style5a = 'id="butonmeniux"';}else{$id_style5a = 'id="butonmeniu"';}
echo'
<div id="meniuorizontal">
	<div id="butoaneorizontal">
	<a href="index.php?pag=1b" alt="" title="">
		<div '.$id_style1b.'>'.$_SESSION['nume_pag1b'].'</div>
	</a>
	<a href="index.php?pag=1a" alt="" title="">
		<div '.$id_style1a.'>'.$_SESSION['nume_pag1a'].'</div>
	</a>
	<a href="index.php?pag=2a" alt="" title="">
		<div '.$id_style2a.'>'.$_SESSION['nume_pag2a'].'</div>
	</a>';
// echo'<a href="index.php?pag=3a" alt="" title="">
		// <div '.$id_style3a.'>'.$_SESSION['nume_pag3a'].'</div>
	// </a>';
echo'<a href="index.php?pag=4" alt="" title="">
		<div '.$id_style4a.'>'.$_SESSION['nume_pag4a'].'</div>
	</a>';
	//echo' <a href="index.php?pag=5a" alt=" title=">
		// <div '.$id_style5a.'>'.$_SESSION['nume_pag5a'].'</div>
	// </a>';
echo '</div>';
echo '</div>';

}
?>
