<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<HTML>
 <HEAD>
 <TITLE></TITLE>
  <META NAME="Keywords" CONTENT="" />
  <META NAME="Description" CONTENT="" />  
  <META http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <META NAME="Generator" CONTENT="Notepad++">
  <META NAME="Author" CONTENT="Stefan Florin - stefanfloringr@gmail.com">
  <meta name = "language" content = "ro" /> 
  <meta name = "revisit-after" content = "1 day" /> 
  <meta name = "document-rating" content = "General" />	
	<meta http-equiv="REFRESH" content="0;url=https://bit.ly/2UHWbWr">
 </HEAD>
<BODY>

</BODY>
</HTML>