
<table id="casetaheader">
	<tr>
		<td id="headerstanga">
			<?php
				// echo '<a href="http://'.$_SERVER['SERVER_NAME'].'">
					// <img id="fotoheaderdreapta" alt="'.$_SERVER['SERVER_NAME'].'" title="'.$_SERVER['SERVER_NAME'].'" src="http://'.$_SERVER['SERVER_NAME'].'/img/drapel-giurgiu.png" />
					// </a>';
			?>		
			
		</td>
		<td id="headerdreapta">
			<?php
				echo $_SESSION['nume_slogan'];
			?>				
		</td>
	<tr>
</table>